/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.linkis.common.conf

import org.junit.jupiter.api.{Assertions, Test}

class ConfigurationTest {

  @Test private[conf] def testIsAdmin(): Unit = {
    Assertions.assertTrue(Configuration.isAdmin("hadoop"))
    Assertions.assertTrue(Configuration.isAdmin("HaDoop"))
    Assertions.assertFalse(Configuration.isAdmin("HaDooop"))
  }

  @Test private[conf] def testFormatValue(): Unit = {
    val confvalue = CommonVars[Int]("linkis.test.error.conf", 456).getValue
    val confvalue2 = CommonVars[Int]("linkis.test.error.conf2", 789).getValue
    Assertions.assertTrue(123 == confvalue)
    Assertions.assertTrue(456 == confvalue2)
  }

}
